===========
Release 2.3
===========

Bug Fixes and Enhancements
--------------------------
* Update the default JVM settings to use the new -XX:+ExitOnOutOfMemoryError flag instead of the old -XX:OnOutOfMemoryError=kill -9 %p
